"use strict";

var _includeRoutes = _interopRequireDefault(require("../includeRoutes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe("includeRoutes", function () {
  it("should return flattened version of provided routes", function () {
    var routes = [{
      path: "/",
      name: "homepage",
      page: "Homepage"
    }, [{
      path: "/es/",
      name: "homepage",
      page: "Homepage"
    }]];
    var expected = [{
      path: "/",
      name: "homepage",
      page: "Homepage"
    }, {
      path: "/es/",
      name: "homepage",
      page: "Homepage"
    }];
    expect((0, _includeRoutes.default)({
      routes: routes
    })).toEqual(expected);
  });
  it("should add provided params to all included routes", function () {
    var routes = [{
      path: "/",
      name: "homepage",
      page: "Homepage"
    }];
    var expected = [{
      path: "/",
      name: "homepage",
      page: "Homepage",
      params: {
        foo: "foo",
        bar: "bar"
      }
    }];
    expect((0, _includeRoutes.default)({
      routes: routes,
      params: {
        foo: "foo",
        bar: "bar"
      }
    })).toEqual(expected);
  });
  it("should add allow route params to override included params", function () {
    var routes = [{
      path: "/",
      name: "homepage",
      page: "Homepage",
      params: {
        foo: "overridden"
      }
    }];
    var expected = [{
      path: "/",
      name: "homepage",
      page: "Homepage",
      params: {
        foo: "overridden",
        bar: "bar"
      }
    }];
    expect((0, _includeRoutes.default)({
      routes: routes,
      params: {
        foo: "foo",
        bar: "bar"
      }
    })).toEqual(expected);
  });
  it("should add allow prefixing of included route paths", function () {
    var routes = [{
      path: "/",
      name: "homepage",
      page: "Homepage",
      params: {
        foo: "overridden"
      }
    }];
    var expected = [{
      path: "/es/",
      name: "homepage",
      page: "Homepage",
      params: {
        foo: "overridden",
        bar: "bar"
      }
    }];
    expect((0, _includeRoutes.default)({
      routes: routes,
      prefix: "/es/",
      params: {
        foo: "foo",
        bar: "bar"
      }
    })).toEqual(expected);
  });
});