"use strict";

var _reverse = _interopRequireDefault(require("../reverse"));

var _compileRoutes = _interopRequireDefault(require("../compileRoutes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe("reverse", function () {
  it("should return null when routes are empty", function () {
    expect((0, _reverse.default)([], "foo")).toEqual(null);
  });
  it("should return null when there isn't a match", function () {
    var routes = (0, _compileRoutes.default)([{
      path: "/bar/",
      name: "bar",
      page: "Bar"
    }]);
    expect((0, _reverse.default)(routes, "foo")).toEqual(null);
  });
  it("should return params for simple matches", function () {
    var routes = (0, _compileRoutes.default)([{
      path: "/bar/",
      name: "bar",
      page: "Bar"
    }, {
      path: "/foo/",
      name: "foo",
      page: "Foo"
    }]);
    expect((0, _reverse.default)(routes, "foo")).toEqual({
      as: "/foo/",
      href: {
        pathname: "/Foo",
        query: {}
      }
    });
  });
  it("should return params for parameterised URLs", function () {
    var routes = (0, _compileRoutes.default)([{
      path: "/:slug/",
      name: "foo",
      page: "Foo"
    }]);
    expect((0, _reverse.default)(routes, "foo", {
      slug: "foo"
    })).toEqual({
      as: "/foo/",
      href: {
        pathname: "/Foo",
        query: {
          slug: "foo"
        }
      }
    });
  });
  it("should return the correct match if multiple routes have the same name", function () {
    var routes = (0, _compileRoutes.default)([{
      path: "/fake-foo/",
      name: "foo",
      page: "FakeFoo"
    }, {
      path: "/:slug/",
      name: "foo",
      page: "Foo"
    }, {
      path: "/:slug/:another-slug/",
      name: "foo",
      page: "FooChild"
    }]);
    expect((0, _reverse.default)(routes, "foo", {
      slug: "foo"
    })).toEqual({
      as: "/foo/",
      href: {
        pathname: "/Foo",
        query: {
          slug: "foo"
        }
      }
    });
  });
  it("should return the correct match if multiple routes have the same name and use explicit params", function () {
    var routes = (0, _compileRoutes.default)([{
      path: "/fake-foo/",
      name: "foo",
      page: "FakeFoo"
    }, {
      path: "/foo/",
      name: "foo",
      page: "Foo",
      params: {
        slug: "foo"
      }
    }]);
    expect((0, _reverse.default)(routes, "foo", {
      slug: "foo"
    })).toEqual({
      as: "/foo/",
      href: {
        pathname: "/Foo",
        query: {
          slug: "foo"
        }
      }
    });
  });
});