"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = reverse;

var _sortBy2 = _interopRequireDefault(require("lodash/sortBy"));

var _isEqual2 = _interopRequireDefault(require("lodash/isEqual"));

var _every2 = _interopRequireDefault(require("lodash/every"));

var _normalizePage = _interopRequireDefault(require("./normalizePage"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var isSubset = function isSubset(candidate, test) {
  return (0, _every2.default)(candidate, function (val, key) {
    return (0, _isEqual2.default)(val, test[key]);
  });
};
/**
 * Given a view name and params, will return both the Next route params and the
 * display URL
 */


function reverse(routes, name) {
  var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  if (routes.length === 0) {
    return null;
  }
  /*
   * For a match to occur, every dynamic parameter in the path must be supplied.
   * Additionally, we sort so that the routes with the *most* dynamic parameters
   * take priority, so that a more specific match wins over a generic one.
   */


  var candidateRoutes = (0, _sortBy2.default)(routes.filter(function (route) {
    return route.name === name && route.allKeyNames.every(function (keyName) {
      return Object.keys(params).includes(keyName);
    }) && isSubset(route.params, params);
  }), function (route) {
    return -route.allKeyNames.length;
  });

  if (candidateRoutes.length === 0) {
    return null;
  }

  var route = candidateRoutes[0];
  return {
    as: route.toPath(params),
    href: {
      pathname: (0, _normalizePage.default)(route.page),
      query: _objectSpread({}, route.params, params)
    }
  };
}